sequencetools.is_monotonically_increasing_sequence
==================================================

.. autofunction:: abjad.tools.sequencetools.is_monotonically_increasing_sequence.is_monotonically_increasing_sequence
